(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29998,        605]*)
(*NotebookOutlinePosition[     30642,        627]*)
(*  CellTagsIndexPosition[     30598,        623]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{\(Off[General::"\<spell\>"];\), "\[IndentingNewLine]", \(Off[
        General::"\<spell1\>"];\), "\n", 
    RowBox[{"<<", 
      StyleBox[
        RowBox[{"Statistics", 
          StyleBox["`",
            "MB"], "MultinormalDistribution", 
          StyleBox["`",
            "MB"]}]]}], "\n", \(<< 
      Statistics`ContinuousDistributions`\), "\[IndentingNewLine]", \(<< 
      Statistics`DiscreteDistributions`\), "\[IndentingNewLine]", \(<< 
      Graphics`MultipleListPlot`\), "\[IndentingNewLine]", \(<< 
      Graphics`Graphics`\), "\[IndentingNewLine]", \(<< 
      Statistics`DataManipulation`\), "\[IndentingNewLine]", \(workdirectory \
= "\<Z:\chaozhi\modelIrealdata\\run3\>";\), "\[IndentingNewLine]", \
\(SetDirectory[
      workdirectory]\), "\[IndentingNewLine]", \(<< 
        MCMCAlgorithms.m;\)}], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(Import\)\)\ data\ and\ covarates **  **  **  **  **  **  **  **  **  **  **  \
**  ** *\(\(**\)\(**\)\)**********) \)], "Input"],

Cell[BoxData[{
    \(\(SetDirectory[workdirectory];\)\), "\[IndentingNewLine]", 
    \(\(data = 
        Import["\<realdata.txt\>", "\<TSV\>"];\)\), "\[IndentingNewLine]", 
    \(\(covariates = Import["\<covariates.txt\>", "\<TSV\>"];\)\)}], "Input"],

Cell[BoxData[{
    \(\({sex, poptype, eclosion, jstart} = 
        Transpose[
          covariates[\([All, {2, 3, 4, 5}]\)]];\)\), "\[IndentingNewLine]", 
    \(\(jlast = \(Import["\<jlast.txt\>", "\<TSV\>"]\)[\([All, 
            2]\)];\)\), "\[IndentingNewLine]", 
    \(\(weather = 
        Import["\<weather.txt\>", "\<TSV\>"];\)\), "\[IndentingNewLine]", 
    \(\({time, T} = Transpose[weather];\)\), "\[IndentingNewLine]", 
    \(\({N0, tmax} = Dimensions[data];\)\)}], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*
        Initialize\ parameters **  **  **  **  **  **  **  **  **  **  **  **  \
**  **  **  **  **  ** **********) \)], "Input"],

Cell[BoxData[
    \(\(LargeNumber = 10^6;\)\)], "Input"],

Cell[BoxData[{
    \(\(SeedRandom[5749];\)\), "\[IndentingNewLine]", 
    \(\(paraslabel = {\*"\"\<\!\(g\_m\)\>\"", \*"\"\<\!\(g\_T\)\>\"", \*"\"\<\
\!\(g\_s\)\>\"", \*"\"\<\!\(g\_p\)\>\"", \*"\"\<\!\(g\_sp\)\>\"", \*"\"\<\!\(\
\[Sigma]\_g\)\>\"", \*"\"\<\!\(h\_m\)\>\"", \*"\"\<\!\(h\_d\)\>\"", \*"\"\<\!\
\(h\_s\)\>\"", \*"\"\<\!\(h\_p\)\>\"", \*"\"\<\!\(h\_sp\)\>\"", \
\*"\"\<\!\(q\_m\)\>\"", \*"\"\<\!\(q\_s\)\>\"", \*"\"\<\!\(q\_p\)\>\"", \*"\"\
\<\!\(q\_sp\)\>\""};\)\), "\[IndentingNewLine]", 
    \(\({gT, gs, gp, gsp, hd, hs, hp, hsp, qs, qp, qsp} = 
        RandomArray[NormalDistribution[0, 0.5], 
          11];\)\), "\[IndentingNewLine]", 
    \(\(gm = \(-\((gT + gs + gp + gsp)\)\);\)\), "\[IndentingNewLine]", 
    \(\({sdg, pxsdh, lambdah} = 
        RandomArray[HalfNormalDistribution[1], 
          3];\)\), "\[IndentingNewLine]", 
    \(\(qm = \(-\((qs + qp + qsp)\)\);\)\), "\[IndentingNewLine]", 
    \(\(hm = \(-2.3\) - \((hd + hs + hp + 
              hsp)\);\)\), "\[IndentingNewLine]", 
    \(\(paras = {gm, gT, gs, gp, gsp, sdg, hm, hd, hs, hp, hsp, qm, qs, qp, 
          qsp};\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(jdead = jlast;\)\), "\[IndentingNewLine]", 
    \(\(dg = 
        Table[Random[NormalDistribution[0, sdg]], {i, 1, 
            N0}];\)\), "\[IndentingNewLine]", 
    \(\(dgsigma = Table[Null, {i, N0}];\)\), "\[IndentingNewLine]", 
    \(\(SeedRandom[];\)\)}], "Input"],

Cell[BoxData[
    \({paraslabel, paras} // MatrixForm\)], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\) **  \
**  **  **  **  **  **  **  **  **  **  **  **  **  ** **********) \)], \
"Input"],

Cell[BoxData[
    \(\(\(\(sumind = Total[Transpose[data]];\)\[IndentingNewLine]
    \(sumdata = Total[Total[data]];\)\[IndentingNewLine]
    \(sumT = Total[data . T];\)\[IndentingNewLine]
    \(sumsex = Total[sex . data];\)\[IndentingNewLine]
    \(sumpop = Total[poptype . data];\)\[IndentingNewLine]
    \(sumsexpop = Total[\((poptype\ sex)\) . data];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\)*\(\(**\)\(Define\)\)\ \(functions **  **  ** \) **  **  **  **  **  **  **  \
**  **  **  **  **  **  **  ** **********) \)], "Input"],

Cell[BoxData[
    \(\(riseset = 
        Sort[Flatten[
            Table[{k + 7/24. , k + 19/24. }, {k, 0, 
                IntegerPart[time[\([tmax]\)]]}]]];\)\)], "Input"],

Cell[BoxData[
    \(\(DeathProb[i_, j_, hm_, hd_, hs_, hp_, hsp_, dhi_, qm_, qs_, qp_, 
          qsp_, IsAll_] := 
        Module[{slope, temp, subtime, oneday, 
            res}, \[IndentingNewLine]trend[
              t_] := \((t - eclosion[\([i]\)])\)\ \ \((qm + 
                  qp\ poptype[\([i]\)] + qs\ sex[\([i]\)] + 
                  qsp\ poptype[\([i]\)]\ sex[\([i]\)])\); \
\[IndentingNewLine]starttime = 
            If[IsAll\  || \ \((j \[Equal] jstart[\([i]\)])\), 
              eclosion[\([i]\)], 
              time[\([j - 1]\)]]; \[IndentingNewLine]subtime = 
            Sort[Select[Union[riseset, {starttime, time[\([j]\)]}], 
                time[\([j]\)] \[GreaterEqual] # \[GreaterEqual] 
                    starttime &]]; \[IndentingNewLine]oneday = 
            Mod[subtime, 1]; \[IndentingNewLine]temp = 
            hm + hs\ sex[\([i]\)] + hp\ poptype[\([i]\)] + 
              hsp\ sex[\([i]\)]\ poptype[\([i]\)] + 
              dhi; \[IndentingNewLine]res = 
            Sum[Exp[temp + 
                    hd\ If[19/24.  > oneday[\([k - 1]\)] \[GreaterEqual] 
                          7/24. , 1, \(-1\)]]\ NIntegrate[
                  Exp[trend[t]], {t, subtime[\([k - 1]\)], 
                    subtime[\([k]\)]}], {k, 2, 
                Length[subtime]}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(DeathProb2[i_, j_, hm_, hd_, hs_, hp_, hsp_, dhi_, qm_, qs_, qp_, 
          qsp_, IsAll_] := 
        Module[{slope, temp, subtime, oneday, 
            res}, \[IndentingNewLine]trend[
              t_] := \((t - eclosion[\([i]\)])\)\ \ \((qm + 
                  qp\ poptype[\([i]\)] + qs\ sex[\([i]\)] + 
                  qsp\ poptype[\([i]\)]\ sex[\([i]\)])\); \
\[IndentingNewLine]starttime = 
            If[IsAll\  || \ \((j \[Equal] jstart[\([i]\)])\), 
              eclosion[\([i]\)], 
              time[\([j - 1]\)]]; \[IndentingNewLine]subtime = 
            Sort[Select[Union[riseset, {starttime, time[\([j]\)]}], 
                time[\([j]\)] \[GreaterEqual] # \[GreaterEqual] 
                    starttime &]]; \[IndentingNewLine]oneday = 
            Mod[subtime, 1]; \[IndentingNewLine]temp = 
            hm + hs\ sex[\([i]\)] + hp\ poptype[\([i]\)] + 
              hsp\ sex[\([i]\)]\ poptype[\([i]\)] + 
              dhi; \[IndentingNewLine]res = 
            Sum[Exp[temp + 
                    hd\ If[19/24.  > oneday[\([k - 1]\)] \[GreaterEqual] 
                          7/24. , 1, \(-1\)]]\ Exp[
                  trend[subtime[\([k - 1]\)]]]\ \((subtime[\([k]\)] - 
                    subtime[\([k - 1]\)])\), {k, 2, 
                Length[subtime]}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\) **  \
**  **  ** *\(\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\)**********) \)], "Input"],

Cell[BoxData[
    \( (*\(\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)\
\(**\)\)*MCMC\ \(options **  **  ** \) **  **  **  **  **  **  **  ** *\(\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \)], "Input"],

Cell[BoxData[
    \(\(\( (*Set\ scale\ factor\ and\ initialize\ the\ accept\ for\ \
Metropolis\ Algorithm\ within\ Gibbs\ \
sampler*) \)\(\[IndentingNewLine]\)\(\(SeedRandom[];\)\[IndentingNewLine]
    \(totaldraws = 1000000;\)\[IndentingNewLine]
    \(monitor = True;\)\[IndentingNewLine]
    \(factordh = Table[1, {i, N0}];\)\n
    \(factormuh = 1.0;\)\ \[IndentingNewLine]
    \(factordg = Table[1, {i, N0}];\)\[IndentingNewLine]
    \(factormug = 1.0;\)\[IndentingNewLine]
    \(factorlh = 1;\)\)\)\)], "Input"],

Cell[BoxData[{
    \(acceptdh = 
      Table[0, {i, N0}]; \  (*dh[i]*) \[IndentingNewLine]acceptmuh = 
      0; \  (*\ hm, hd, hs, hp, hsp, qm, qp, qs, 
      and\ qsp*) \), "\[IndentingNewLine]", 
    \(acceptdg = 
      Table[0, {i, N0}]; \  (*dg[i]*) \[IndentingNewLine]acceptmug = 
      0; \  (*gm, gT, gs, gp, 
      and\ gsp*) \ \[IndentingNewLine] (*lambda*) \ \
\[IndentingNewLine]acceptlh = 0;\)}], "Input"],

Cell[BoxData[
    \( (*\(\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)\
\(**\)\)*Gibbs\ Sampler **  **  **  **  **  **  **  **  **  **  \
** *\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \
\)], "Input"],

Cell[BoxData[{
    \(\(scaleadjust[scale_, cr_, tr_] := 
        Module[{a = 2}, \[IndentingNewLine]If[Abs[cr - tr] \[LessEqual] 0.02, 
            scale, scale\ Exp[
                a\ \((cr - 
                      tr)\)]]\[IndentingNewLine]];\)\), \
"\[IndentingNewLine]", 
    \(\(cr = Table[0.1\ i, {i, 0, 10}];\)\), "\[IndentingNewLine]", 
    \(\(crs = 
        Table[scaleadjust[1, cr[\([i]\)], 0.44], {i, 
            Length[cr]}];\)\), "\[IndentingNewLine]", 
    \({cr, crs} // MatrixForm\)}], "Input"],

Cell[BoxData[
    \( (*\(\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)\
\(**\)\)*Gibbs\ Sampler **  **  **  **  **  **  **  **  **  **  \
** *\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \
\)], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*
        Create\ Files\ or\ Resume **  **  **  **  **  **  **  **  **  \
** *\(\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \
\)], "Input"],

Cell[BoxData[
    \(\(Resume = False;\)\)], "Input"],

Cell[BoxData[{
    \(\(If[
        Resume, \[IndentingNewLine]parascheck = 
          ReadList["\<results_paras.txt\>"]; \[IndentingNewLine]jdeadcheck = 
          ReadList["\<results_jdead.txt\>"]; \[IndentingNewLine]dgcheck = 
          ReadList["\<results_dg.txt\>"]; \[IndentingNewLine]\
\[IndentingNewLine]Print[Dimensions[parascheck]]; \[IndentingNewLine]Print[
          Dimensions[jdeadcheck]]; \[IndentingNewLine]Print[
          Dimensions[
            dgcheck]]; \[IndentingNewLine]\[IndentingNewLine]startiteration = \
\(Dimensions[parascheck]\)[\([1]\)], 
        startiteration = 1\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<startiteration=\>", startiteration];\)\)}], "Input"],

Cell[BoxData[
    \(\(If[
        Resume, \[IndentingNewLine]paras = \({gm, gT, gs, gp, gsp, sdg, hm, 
              hd, hs, hp, hsp, qm, qs, qp, qsp} = 
            parascheck[\([\(-1\)]\)]\); \[IndentingNewLine]jead = 
          jdeadcheck[\([\(-1\)]\)]; \[IndentingNewLine]dg = 
          dgcheck[\([\(-1\)]\)]; \[IndentingNewLine]{dhsigma, hsigma, 
            dgsigma, gsigma, lhsigma} = 
          Flatten[ReadList["\<results_sigma.txt\>"], 
            1];\[IndentingNewLine], \[IndentingNewLine] (*Save\ parameters\ \
into\ FILES, \ 
          and\ DELETE\ the\ old\ files*) \[IndentingNewLine]paraslabel >> \
"\<results_paraslabel.txt\>"; \[IndentingNewLine]paras >> \
"\<results_paras.txt\>"; \[IndentingNewLine]jdead >> "\<results_jdead.txt\>"; \
\[IndentingNewLine]dg >> "\<results_dg.txt\>";\[IndentingNewLine]];\)\)], \
"Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*
        Running\ setting **  **  **  ** \
\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\)**********) \)], "Input"],

Cell[BoxData[{
    \(\(SeedRandom[];\)\), "\[IndentingNewLine]", 
    \(\(totaldraws = 40002;\)\), "\[IndentingNewLine]", 
    \(\(monitor = False;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(factordh = Table[1, {i, N0}];\)\), "\n", 
    \(\(factormuh = 1.06;\)\ \), "\[IndentingNewLine]", 
    \(\(factordg = Table[1, {i, N0}];\)\), "\[IndentingNewLine]", 
    \(\(factormug = 1.12;\)\), "\[IndentingNewLine]", 
    \(\(factorlh = 1;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(aptolddh = \(aptoldmuh = \(aptolddg = \(aptoldmug = \(aptoldlh = 
                0\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(acceptdh = 
      Table[0, {i, N0}]; \  (*dh[i]*) \[IndentingNewLine]acceptmuh = 
      0; \  (*\ hm, hd, hs, hp, hsp, qm, qp, qs, and\ qsp*) \n
    acceptdg = Table[0, {i, N0}]; \  (*dg[i]*) \[IndentingNewLine]acceptmug = 
      0; \  (*gm, gT, gs, gp, 
      and\ gsp*) \ \[IndentingNewLine] (*lambda*) \ \
\[IndentingNewLine]acceptlh = 0;\)}], "Input"],

Cell[BoxData[
    \( (*\(\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)\
\(**\)\)*Gibbs\ Sampler **  **  **  **  **  **  **  **  **  **  \
** *\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \
\)], "Input"],

Cell[BoxData[
    \(\(dh = Table[0, {i, N0}];\)\)], "Input"],

Cell[BoxData[
    \( (*\(\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)\
\(**\)\)*Gibbs\ Sampler **  **  **  **  **  **  **  **  **  **  \
** *\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)**********) \
\)], "Input"],

Cell[BoxData[
    \(iteration\)], "Input"],

Cell[BoxData[
    \(startiteration\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"For", "[", 
        RowBox[{\(iteration = startiteration\), 
          ",", \(iteration \[LessEqual] totaldraws\), ",", \(iteration++\), 
          ",", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"Print", "[", 
              RowBox[{"Timing", "[", "\[IndentingNewLine]", 
                
                RowBox[{\(condition = 
                    Which[iteration \[LessEqual] 
                        101, \((Mod[iteration, 20] \[Equal] 1)\), True, 
                      False]\), ";", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(If[monitor, 
                    Print["\<start to sample jdead ...\>"]]\), ";", 
                  "\[IndentingNewLine]", \( (*Calculate\ intermediate\ \
quantities\ hh\ and\ g\ from\ initial\ parameters*) \), 
                  "\[IndentingNewLine]", \(hh = 
                    Table[If[j < jlast[\([i]\)], Null, 
                        temp = 
                          DeathProb[i, j, hm, hd, hs, hp, hsp, dh[\([i]\)], 
                            qm, qs, qp, qsp, False]; 
                        Which[temp < 10^\((\(-12\))\), temp, temp > 10^7, 1, 
                          True, 1 - Exp[\(-temp\)]]], {i, N0}, {j, tmax}]\), 
                  ";", "\[IndentingNewLine]", \(g = 
                    Table[If[j < jlast[\([i]\)], Null, 
                        AAlogit[
                          gm + gT\ T[\([j]\)] + gs\ sex[\([i]\)] + 
                            gp\ poptype[\([i]\)] + 
                            gsp\ sex[\([i]\)]\ poptype[\([i]\)] + 
                            dg[\([i]\)]]], {i, N0}, {j, tmax}]\), ";", 
                  "\[IndentingNewLine]", \( (*Sample\ n\ by\ inverse\ \
CDF*) \), "\[IndentingNewLine]", \(Do[\[IndentingNewLine]npdf = 
                      Table[If[m == tmax, 1, \ 
                            hh[\([i, 
                                m + 1]\)]]\ \(\[Product]\+\(j = \
jlast[\([i]\)]\)\%m\((\((1 - g[\([i, j]\)])\) \((1 - 
                                    hh[\([i, j]\)])\))\)\), {m, 
                          jlast[\([i]\)], tmax}]; \[IndentingNewLine]If[
                      Total[npdf] \[Equal] 0, 
                      npdf[\([\(-1\)]\)] = 
                        1]; \[IndentingNewLine]jdead[\([i]\)] = 
                      RRandomInverseCDF[npdf, 
                        jlast[\([i]\)]]\[IndentingNewLine], {i, N0}]\), ";", 
                  "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(priorhv = 16\), ";", 
                  "\[IndentingNewLine]", \(ptv = 16\), ";", 
                  "\[IndentingNewLine]", \(If[monitor, 
                    Print["\<start to sample hm,hd,hs,hp,hsp,qm,qs,qp,qsp ...\
\>"]]\), ";", 
                  "\[IndentingNewLine]", \( (*\(Sample\ hm ... \)\ by\ Random\
\ Walk\ Metropolis\ Algorithm*) \), 
                  "\[IndentingNewLine]", \(If[
                    condition, \[IndentingNewLine]logprobmuh[{x1_, x2_, x3_, 
                          x4_, x5_, x6_, x7_, x8_, 
                          x9_}] := \(-\(\((x1 + 
                                    2.3)\)^2\/\(2\ priorhv\)\)\) - 
                        x2^2\/\(2\ priorhv\) - x3^2\/\(2\ priorhv\) - 
                        x4^2\/\(2\ priorhv\) - x5^2\/\(2\ priorhv\) - 
                        x6^2\/\(2\ ptv\) - x7^2\/\(2\ ptv\) - 
                        x8^2\/\(2\ ptv\) - 
                        x9^2\/\(2\ ptv\) + \[Sum]\+\(i = 1\)\%N0\((If[
                                jdead[\([i]\)] < tmax, 
                                temp = 
                                  DeathProb2[i, jdead[\([i]\)] + 1, x1, x2, 
                                    x3, x4, x5, dh[\([i]\)], x6, x7, x8, x9, 
                                    False]; \[IndentingNewLine]Log[
                                  temp - temp^2/2 + temp^3/6], 0] - 
                              DeathProb2[i, jdead[\([i]\)], x1, x2, x3, x4, 
                                x5, dh[\([i]\)], x6, x7, x8, x9, 
                                True])\); \[IndentingNewLine]maxpoint = 
                      NMaximize[
                        logprobmuh[{x1, x2, x3, x4, x5, x6, x7, x8, 
                            x9}], {x1, x2, x3, x4, x5, x6, x7, x8, 
                          x9}]; \[IndentingNewLine]Print[
                      maxpoint]; \[IndentingNewLine]hsigma = 
                      SSigma[logprobmuh, 
                        maxpoint[\([2]\)]]; \
\[IndentingNewLine]Print["\<hsigma=\>", 
                      hsigma // MatrixForm]; \[IndentingNewLine]{hm, hd, hs, 
                        hp, hsp, qm, qs, qp, 
                        qsp} = {x1, x2, x3, x4, x5, x6, x7, x8, x9} /. 
                        maxpoint[\([2]\)], \[IndentingNewLine]\
\[IndentingNewLine]logprobmuh[{x1_, x2_, x3_, x4_, x5_, x6_, x7_, x8_, 
                          x9_}] := \(-\(\((x1 + 
                                    2.3)\)^2\/\(2\ priorhv\)\)\) - 
                        x2^2\/\(2\ priorhv\) - x3^2\/\(2\ priorhv\) - 
                        x4^2\/\(2\ priorhv\) - x5^2\/\(2\ priorhv\) - 
                        x6^2\/\(2\ ptv\) - x7^2\/\(2\ ptv\) - 
                        x8^2\/\(2\ ptv\) - 
                        x9^2\/\(2\ ptv\) + \[Sum]\+\(i = 1\)\%N0\((If[
                                jdead[\([i]\)] < tmax, 
                                temp = 
                                  DeathProb[i, jdead[\([i]\)] + 1, x1, x2, 
                                    x3, x4, x5, dh[\([i]\)], x6, x7, x8, x9, 
                                    False]; \[IndentingNewLine]Which[
                                  temp \[LessEqual] 10^\((\(-12\))\), 
                                  Log[temp], temp > 10^7, 0, True, 
                                  Log[1 - Exp[\(-temp\)]]], 0] - 
                              DeathProb[i, jdead[\([i]\)], x1, x2, x3, x4, 
                                x5, dh[\([i]\)], x6, x7, x8, x9, 
                                True])\); \[IndentingNewLine]temp = 
                      MMetropolisRandomWalk[{hm, hd, hs, hp, hsp, qm, qs, qp, 
                          qsp}, logprobmuh, \((factormuh\ 2.4/
                                  Sqrt[9])\)^2\ hsigma]; \
\[IndentingNewLine]{hm, hd, hs, hp, hsp, qm, qs, qp, qsp} = 
                      temp[\([1]\)]; \[IndentingNewLine]If[
                      temp[\([2]\)], \(acceptmuh++\)];\[IndentingNewLine]]\), 
                  ";", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(If[monitor, 
                    Print["\<start to sample gm,gT,gs,gp,and gsp...\>"]]\), 
                  ";", "\[IndentingNewLine]", \( (*\(Sample\ gm ... \)\ by\ \
Random\ Walk\ Metropolis\ Algorithm*) \), 
                  "\[IndentingNewLine]", \(logprobmug[{x1_, x2_, x3_, x4_, 
                        x5_}] = \(-\(x1^2\/\(2\ LargeNumber\)\)\) - 
                      x2^2\/\(2\ LargeNumber\) - x3^2\/\(2\ LargeNumber\) - 
                      x4^2\/\(2\ LargeNumber\) - x5^2\/\(2\ LargeNumber\) + 
                      x1\ sumdata + x2\ sumT + x3\ sumsex + x4\ sumpop + 
                      x5\ sumsexpop - \[Sum]\+\(i = 1\)\%N0\((\[Sum]\+\(j = \
jstart[\([i]\)]\)\%\(jdead[\([i]\)]\)\((Log[
                                1 + Exp[
                                    x1 + x2\ \ T[\([j]\)] + 
                                      x3\ \ sex[\([i]\)] + 
                                      x4\ \ poptype[\([i]\)] + 
                                      x5\ \ \ sex[\([i]\)]\ poptype[\([i]\)] \
+ \ dg[\([i]\)]]])\))\)\), ";", 
                  "\[IndentingNewLine]", \(If[
                    condition, \[IndentingNewLine]maxpoint = 
                      NMaximize[
                        logprobmug[{x1, x2, x3, x4, x5}], {x1, x2, x3, x4, 
                          x5}]; \[IndentingNewLine]Print[
                      maxpoint]; \[IndentingNewLine]gsigma = 
                      SSigma[logprobmug, 
                        maxpoint[\([2]\)]]; \
\[IndentingNewLine]Print["\<gsigma=\>", 
                      gsigma // MatrixForm]; \[IndentingNewLine]{gm, gT, gs, 
                        gp, gsp} = {x1, x2, x3, x4, x5} /. 
                        maxpoint[\([2]\)], \[IndentingNewLine]\
\[IndentingNewLine]temp = 
                      MMetropolisRandomWalk[{gm, gT, gs, gp, gsp}, 
                        logprobmug, \((factormug\ 2.4/
                                  Sqrt[5])\)^2\ gsigma]; \
\[IndentingNewLine]{gm, gT, gs, gp, gsp} = 
                      temp[\([1]\)]; \[IndentingNewLine]If[
                      temp[\([2]\)], \(acceptmug++\)];\[IndentingNewLine]]\), 
                  ";", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(If[monitor, 
                    Print["\<start to sample dg...\>"]]\), ";", 
                  "\[IndentingNewLine]", \( (*Sample\ dg\ by\ Random\ Walk\ \
Metropolis\ Algorithm*) \), 
                  "\[IndentingNewLine]", \
\(Do[\[IndentingNewLine]logprobdg[{x1_}] = \(-\(x1^2\/\(2\ sdg^2\)\)\) + 
                        x1\ sumind[\([i]\)] - 
                        Sum[Log[
                            1 + Exp[
                                gm + gT\ T[\([j]\)] + \ gs\ sex[\([i]\)] + \ 
                                  gp\ poptype[\([i]\)] + \ 
                                  gsp\ sex[\([i]\)]\ poptype[\([i]\)] + 
                                  x1]], {j, jstart[\([i]\)], 
                            jdead[\([i]\)]}];  (*sumind = 
                        Sum[data[\([i, j]\)], {j, jstart[\([i]\)], 
                            jdead[\([i]\)]}]*) \[IndentingNewLine]If[
                      condition, \[IndentingNewLine]maxpoint = 
                        NMaximize[logprobdg[{x1}], 
                          x1]; \[IndentingNewLine]dgsigma[\([i]\)] = 
                        SSigma[logprobdg, 
                          maxpoint[\([2]\)]]; \[IndentingNewLine]dg[\([i]\)] \
= x1 /. maxpoint[\([2]\)], \[IndentingNewLine]\[IndentingNewLine]temp = 
                        MMetropolisRandomWalk[{dg[\([i]\)]}, 
                          logprobdg, \((factordg[\([i]\)]\ 2.4)\)^2\ dgsigma[\
\([i]\)]]; \[IndentingNewLine]{dg[\([i]\)]} = 
                        temp[\([1]\)]; \[IndentingNewLine]If[
                        temp[\([2]\)], \(acceptdg[\([i]\)]++\)]\
\[IndentingNewLine]];\[IndentingNewLine], {i, N0}]\), ";", 
                  "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \(If[monitor, 
                    Print["\<start to sample sdg ...\>"]]\), ";", 
                  "\[IndentingNewLine]", \( (*prior\ \(distribution : \ 
                        Uniform[0, A]\ on\ the\ scale\ of\ sdg\)\ *) \), 
                  "\[IndentingNewLine]", \(gdist = 
                    GammaDistribution[\(N0 - 1\)\/2, 2\/Total[dg^2]]\), ";", 
                  "\[IndentingNewLine]", \(sdg = \@\(1/Random[gdist]\)\), ";",
                   "\[IndentingNewLine]", \(While[
                    sdg > LargeNumber\  || \ sdg < 0, 
                    sdg = \@\(1/Random[gdist]\)]\), ";", 
                  "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \( (*save\ running\ environment\ so\ \
that\ it\ can\ be\ recovered\ and\ continue*) \), 
                  "\[IndentingNewLine]", \(If[
                    condition, {dhsigma, hsigma, dgsigma, gsigma, 
                        lhsigma} >> "\<results_sigma.txt\>"]\), ";", 
                  "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \( (*Append\ parameters\ to\ FILES\
*) \), "\[IndentingNewLine]", \(paras = {gm, gT, gs, gp, gsp, sdg, hm, hd, 
                      hs, hp, hsp, qm, qs, qp, qsp}\), ";", 
                  "\[IndentingNewLine]", \(paras >>> \
"\<results_paras.txt\>"\), ";", 
                  "\[IndentingNewLine]", \(jdead >>> \
"\<results_jdead.txt\>"\), ";", 
                  "\[IndentingNewLine]", \(dg >>> "\<results_dg.txt\>"\), ";",
                   "\[IndentingNewLine]", 
                  
                  "\[IndentingNewLine]", \( (*Move\ nonzero\ mean\ of\ \
individual\ difference\ to\ mean\ value*) \), 
                  "\[IndentingNewLine]", \(dg -= Mean[dg]\), 
                  ";", \(gm += Mean[dg]\), ";", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \( (*Monitor\ output\ of\ parameters\
*) \), "\[IndentingNewLine]", 
                  RowBox[{"Print", "[", 
                    RowBox[{
                    "\"\<it.=\>\"", ",", "iteration", ",", 
                      "\"\<,\!\(\*GridBox[{
{hm, hs, hp, \(\(hsp\)\(\\\ \)\), hd},
{qm, qs, qp, qsp, sdg},
{gm, gs, gp, gsp, gT},
{aptmuh, aptmug, aptdg, \[Placeholder], \[Placeholder]},
{fctmuh, fctmug, fctdg, \[Placeholder], \[Placeholder]}
},
GridFrame->True,
RowLines->True,
ColumnLines->True]\)=\>\"", 
                      ",", \({{hm, hs, hp, hsp, hd}, {qm, qs, qp, qsp, 
                            sdg}, {gm, gs, gp, gsp, 
                            gT}, {acceptmuh, acceptmug, Mean[acceptdg], 0, 
                              0}/\((iteration - startiteration + 
                                1. )\)\ , {factormuh, factormug, 
                            factordg[\([1]\)], Null, Null}} // MatrixForm\)}],
                     "]"}], ";"}], "\[IndentingNewLine]", "]"}], "]"}], 
            ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input"],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\) **  \
**  **  ** *\(\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(\
**\)\(**\)\(**\)\(**\)\)**********) \)], "Input"]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 839, 17, 230, "Input"],
Cell[2596, 70, 303, 4, 30, "Input"],
Cell[2902, 76, 250, 4, 70, "Input"],
Cell[3155, 82, 484, 9, 110, "Input"],
Cell[3642, 93, 298, 4, 30, "Input"],
Cell[3943, 99, 56, 1, 30, "Input"],
Cell[4002, 102, 1155, 20, 190, "Input"],
Cell[5160, 124, 292, 6, 90, "Input"],
Cell[5455, 132, 66, 1, 30, "Input"],
Cell[5524, 135, 336, 5, 30, "Input"],
Cell[5863, 142, 378, 6, 130, "Input"],
Cell[6244, 150, 310, 4, 30, "Input"],
Cell[6557, 156, 173, 4, 30, "Input"],
Cell[6733, 162, 1332, 24, 210, "Input"],
Cell[8068, 188, 1342, 24, 210, "Input"],
Cell[9413, 214, 379, 5, 30, "Input"],
Cell[9795, 221, 327, 4, 30, "Input"],
Cell[10125, 227, 515, 10, 190, "Input"],
Cell[10643, 239, 417, 9, 130, "Input"],
Cell[11063, 250, 326, 5, 30, "Input"],
Cell[11392, 257, 513, 11, 130, "Input"],
Cell[11908, 270, 326, 5, 30, "Input"],
Cell[12237, 277, 317, 5, 30, "Input"],
Cell[12557, 284, 52, 1, 30, "Input"],
Cell[12612, 287, 715, 12, 250, "Input"],
Cell[13330, 301, 842, 15, 250, "Input"],
Cell[14175, 318, 336, 5, 30, "Input"],
Cell[14514, 325, 986, 17, 350, "Input"],
Cell[15503, 344, 326, 5, 30, "Input"],
Cell[15832, 351, 60, 1, 30, "Input"],
Cell[15895, 354, 326, 5, 30, "Input"],
Cell[16224, 361, 42, 1, 30, "Input"],
Cell[16269, 364, 47, 1, 30, "Input"],
Cell[16319, 367, 13293, 229, 2342, "Input"],
Cell[29615, 598, 379, 5, 30, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

